@@ -1,5 +1,6 @@
 from tibanna_ffcommon.core import API as _API
 from .stepfunction import StepFunctionZebra
+from .stepfunction_cost_updater import StepFunctionCostUpdater
 from .vars import (
     TIBANNA_DEFAULT_STEP_FUNCTION_NAME,
     LAMBDA_TYPE,
@@ -26,6 +27,7 @@ class API(_API):
         return [tibanna, tibanna_ffcommon, tibanna_cgap]
 
     StepFunction = StepFunctionZebra
+    StepFunctionCU = StepFunctionCostUpdater
     default_stepfunction_name = TIBANNA_DEFAULT_STEP_FUNCTION_NAME
     default_env = DEV_ENV
     sfn_type = LAMBDA_TYPE
@@ -46,4 +48,4 @@ class API(_API):
 
     def deploy_zebra(self, suffix=None, usergroup='', setup=False):
         self.deploy_tibanna(suffix=suffix, usergroup=usergroup, setup=False,
-                            buckets=','.join(IAM_BUCKETS))
+                            buckets=','.join(IAM_BUCKETS), deploy_costupdater=True)
